@@ -5,7 +5,7 @@
   
 package Audio::Xmpcr::Network;
 
-$VERSION="0.011";
+$VERSION="0.02";
 
 use strict;
 use IO::Socket::INET;
@@ -55,6 +55,15 @@ sub setchannel {
 	scalar(@ret)==0 ? undef : $ret[0];
 }
 
+# -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+# force the lock
+# -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+sub forcelock {
+  my($self)=@_;
+  my @ret=$self->_doop("forcelock");
+	scalar(@ret)==0 ? undef : $ret[0];
+}
+
 # -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # list 1 or all channels
 # -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -129,6 +138,13 @@ sub processEvents {
 	} @events;
 	@events;
 }
+# -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+# return the server socket FD for select() calls
+# -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+sub eventFd {
+	my($self)=@_;
+	return fileno($self->{s});
+}
 
 # -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # a general send/receive method.
